@@ -7,12 +7,12 @@
 #' @inheritParams install
 #' @param unload if `TRUE` (the default), will automatically unload the
 #'   package prior to uninstalling.
-#' @param ... additional arguments passed to [remove.packages()].
+#' @inheritParams utils::remove.packages
 #' @export
 #' @family package installation
 #' @seealso [with_debug()] to install packages with debugging flags
 #'   set.
-uninstall <- function(pkg = ".", unload = TRUE, quiet = FALSE, ...) {
+uninstall <- function(pkg = ".", unload = TRUE, quiet = FALSE, lib = .libPaths()[[1]]) {
   pkg <- as.package(pkg)
 
   if (unload && pkg$package %in% loaded_packages()$package) {
@@ -20,10 +20,10 @@ uninstall <- function(pkg = ".", unload = TRUE, quiet = FALSE, ...) {
   }
 
   if (!quiet) {
-    message("Uninstalling ", pkg$package)
+    cli::cli_alert_info("Uninstalling {.pkg {pkg$package}}")
   }
 
-  remove.packages(pkg$package)
+  remove.packages(pkg$package, .libPaths()[[1]])
 
   invisible(TRUE)
 }
